@@ -1,7 +1,9 @@
 /* Handles screen manipulations for screen width and inverse mode. */
 #include "screen.h"
 
-#if !defined(hpux) && !defined(__linux__) && !defined(_AIX41)
+#ifdef __linux__
+#include <termcap.h>
+#elif !defined(hpux) && !defined(_AIX41)
 extern "C" int tgetent(void *, const char *);
 extern "C" int tgetnum(const char*);
 extern "C" char *tgetstr(const char *, char**);
