@@ -60,9 +60,9 @@ BitString _nil_BitString;
 
 // break things up into .s indices and positions
 
-inline static int BitStr_len(int l)
+inline static _G_int32_t BitStr_len(_G_int32_t l)
 {
-  return (unsigned)(l) / BITSTRBITS + 1;
+  return (_G_uint32_t)(l) / BITSTRBITS + 1;
 }
 
 
@@ -96,8 +96,8 @@ inline static void check_last(BitStrRep* r)
 
 // merge bits from next word
 
-static inline _BS_word borrow_hi(const _BS_word a[], int ind, 
-                                      int maxind, int p)
+static inline _BS_word borrow_hi(const _BS_word a[], _G_int32_t ind, 
+				 _G_int32_t maxind, int p)
 {
   if (p == 0)
     return a[ind];
@@ -109,8 +109,8 @@ static inline _BS_word borrow_hi(const _BS_word a[], int ind,
 
 // merge bits from prev word
 
-static inline _BS_word borrow_lo(const _BS_word a[], int ind, 
-                                      int minind, int p)
+static inline _BS_word borrow_lo(const _BS_word a[], _G_int32_t ind, 
+                                      _G_int32_t minind, int p)
 {
   _BS_word word = a[ind] _BS_RIGHT (BITSTRBITS - 1 - p);
   if (ind > minind)
@@ -120,8 +120,8 @@ static inline _BS_word borrow_lo(const _BS_word a[], int ind,
 
 // same with bounds check (for masks shorter than patterns)
 
-static inline _BS_word safe_borrow_hi(const _BS_word a[], int ind, 
-                                           int maxind, int p)
+static inline _BS_word safe_borrow_hi(const _BS_word a[], _G_int32_t ind, 
+                                           _G_int32_t maxind, int p)
 {
   if (ind > maxind)
     return 0;
@@ -136,11 +136,11 @@ static inline _BS_word safe_borrow_hi(const _BS_word a[], int ind,
 
 // allocate a new rep; pad to near a power of two
 
-inline static BitStrRep* BSnew(int newlen)
+inline static BitStrRep* BSnew(_G_int32_t newlen)
 {
-  unsigned int siz = sizeof(BitStrRep) + BitStr_len(newlen) * sizeof(_BS_word) 
+   _G_uint32_t siz = sizeof(BitStrRep) + BitStr_len(newlen) * sizeof(_BS_word) 
     + MALLOC_MIN_OVERHEAD;
-  unsigned int allocsiz = MINBitStrRep_SIZE;;
+   _G_uint32_t allocsiz = MINBitStrRep_SIZE;;
   while (allocsiz < siz) allocsiz <<= 1;
   allocsiz -= MALLOC_MIN_OVERHEAD;
   if (allocsiz >= MAXBitStrRep_SIZE * sizeof(_BS_word))
@@ -164,11 +164,11 @@ copy_bits (_BS_word* pdst, _BS_size_t dstbit,
 }
 
 BitStrRep* BStr_alloc(BitStrRep* old, const _BS_word* src,
-                      int startpos, int endp, int newlen)
+                      _G_int32_t startpos, _G_int32_t endp, _G_int32_t newlen)
 {
   if (old == &_nilBitStrRep) old = 0; 
   if (newlen < 0) newlen = 0;
-  int news = BitStr_len(newlen);
+  _G_int32_t news = BitStr_len(newlen);
   BitStrRep* rep;
   if (old == 0 || news > old->sz)
     rep = BSnew(newlen);
@@ -186,7 +186,7 @@ BitStrRep* BStr_alloc(BitStrRep* old, const _BS_word* src,
   return rep;
 }
 
-BitStrRep* BStr_resize(BitStrRep* old, int newlen)
+BitStrRep* BStr_resize(BitStrRep* old, _G_int32_t newlen)
 {
   BitStrRep* rep;
   if (newlen < 0) newlen = 0;
@@ -225,7 +225,7 @@ BitStrRep* BStr_copy(BitStrRep* old, const BitStrRep* src)
   }
   else 
   {
-    int newlen = src->len;
+    _G_int32_t newlen = src->len;
     int news = BitStr_len(newlen);
     if (old == 0 || news  > old->sz)
     {
@@ -252,8 +252,8 @@ int operator == (const BitString& x, const BitString& y)
 
 int operator <= (const BitString& x, const BitString& y)
 {
-  unsigned int  xl = x.rep->len;
-  unsigned int  yl = y.rep->len;
+  _G_uint32_t  xl = x.rep->len;
+  _G_uint32_t  yl = y.rep->len;
   if (xl > yl)
     return 0;
 
@@ -309,7 +309,7 @@ int lcompare(const BitString& x, const BitString& y)
   return _BS_lcompare_0 (x.rep->s, x.rep->len, y.rep->s, y.rep->len);
 }
 
-int BitString::count(unsigned int b) const
+_G_int32_t BitString::count(unsigned int b) const
 {
   int count = _BS_count (rep->s, 0, rep->len);
   if (!b)
@@ -338,9 +338,9 @@ BitStrRep* and(const BitStrRep* x, const BitStrRep* y, BitStrRep* r)
   int xrsame = x == r;
   int yrsame = y == r;
 
-  unsigned int  xl = x->len;
-  unsigned int  yl = y->len;
-  unsigned int  rl = (xl <= yl)? xl : yl;
+  _G_uint32_t  xl = x->len;
+  _G_uint32_t  yl = y->len;
+  _G_uint32_t  rl = (xl <= yl)? xl : yl;
 
   r = BStr_resize(r, rl);
 
@@ -356,9 +356,9 @@ BitStrRep* and(const BitStrRep* x, const BitStrRep* y, BitStrRep* r)
 
 BitStrRep* or(const BitStrRep* x, const BitStrRep* y, BitStrRep* r)
 {
-  unsigned int  xl = x->len;
-  unsigned int  yl = y->len;
-  unsigned int  rl = (xl >= yl)? xl : yl;
+  _G_uint32_t  xl = x->len;
+  _G_uint32_t  yl = y->len;
+  _G_uint32_t  rl = (xl >= yl)? xl : yl;
   int xrsame = x == r;
   int yrsame = y == r;
 
@@ -387,9 +387,9 @@ BitStrRep* or(const BitStrRep* x, const BitStrRep* y, BitStrRep* r)
 
 BitStrRep* xor(const BitStrRep* x, const BitStrRep* y, BitStrRep* r)
 {
-  unsigned int  xl = x->len;
-  unsigned int  yl = y->len;
-  unsigned int  rl = (xl >= yl)? xl : yl;
+  _G_uint32_t  xl = x->len;
+  _G_uint32_t  yl = y->len;
+  _G_uint32_t  rl = (xl >= yl)? xl : yl;
   int xrsame = x == r;
   int yrsame = y == r;
 
@@ -418,8 +418,8 @@ BitStrRep* xor(const BitStrRep* x, const BitStrRep* y, BitStrRep* r)
 
 BitStrRep* diff(const BitStrRep* x, const BitStrRep* y, BitStrRep* r)
 {
-  unsigned int  xl = x->len;
-  unsigned int  yl = y->len;
+  _G_uint32_t  xl = x->len;
+  _G_uint32_t  yl = y->len;
   int xrsame = x == y;
   int yrsame = y == r;
 
@@ -447,9 +447,9 @@ BitStrRep* diff(const BitStrRep* x, const BitStrRep* y, BitStrRep* r)
 
 BitStrRep* cat(const BitStrRep* x, const BitStrRep* y, BitStrRep* r)
 {
-  unsigned int  xl = x->len;
-  unsigned int  yl = y->len;
-  unsigned int  rl = xl + yl;
+  _G_uint32_t  xl = x->len;
+  _G_uint32_t  yl = y->len;
+  _G_uint32_t  rl = xl + yl;
   int xrsame = x == r;
   int yrsame = y == r;
 
@@ -481,7 +481,7 @@ BitStrRep* cat(const BitStrRep* x, const BitStrRep* y, BitStrRep* r)
 
 BitStrRep* cat(const BitStrRep* x, unsigned int bit, BitStrRep* r)
 {
-  unsigned int  xl = x->len;
+  _G_uint32_t  xl = x->len;
   int xrsame = x == r;
   r = BStr_resize(r, xl+1);
   if (!xrsame)
@@ -494,11 +494,11 @@ BitStrRep* cat(const BitStrRep* x, unsigned int bit, BitStrRep* r)
   return r;
 }
 
-BitStrRep* lshift(const BitStrRep* x, int s, BitStrRep* r)
+BitStrRep* lshift(const BitStrRep* x, _G_int32_t s, BitStrRep* r)
 {
   int xrsame = x == r;
-  int  xl = x->len;
-  int  rl = xl + s;
+  _G_int32_t  xl = x->len;
+  _G_int32_t  rl = xl + s;
   if (s == 0)
     r = BStr_copy(r, x);
   else if (rl <= 0)
@@ -530,14 +530,14 @@ BitStrRep* lshift(const BitStrRep* x, int s, BitStrRep* r)
 }
 
 
-void BitString::set(int p)
+void BitString::set(_G_int32_t p)
 {
   if (p < 0) error("Illegal bit index");
-  if ((unsigned)(p) >= rep->len) rep = BStr_resize(rep, p + 1);
+  if ((_G_uint32_t)(p) >= rep->len) rep = BStr_resize(rep, p + 1);
   rep->s[BitStr_index(p)] |= _BS_BITMASK(BitStr_pos(p));
 }
 
-void BitString::assign(int p, unsigned int bit)
+void BitString::assign(_G_int32_t p, _G_uint32_t bit)
 {
   if (p < 0) error("Illegal bit index");
   if ((unsigned)(p) >= rep->len) rep = BStr_resize(rep, p + 1);
@@ -547,7 +547,7 @@ void BitString::assign(int p, unsigned int bit)
       rep->s[BitStr_index(p)] &= ~(_BS_BITMASK(BitStr_pos(p)));
 }
 
-void BitString::clear(int p)
+void BitString::clear(_G_int32_t p)
 {
   if (p < 0) error("Illegal bit index");
   if ((unsigned)(p) >= rep->len) rep = BStr_resize(rep, p + 1);
@@ -569,14 +569,14 @@ void BitString::set()
   check_last(rep);
 }
 
-void BitString::invert(int p)
+void BitString::invert(_G_int32_t p)
 {
   if (p < 0) error("Illegal bit index");
   if ((unsigned)(p) >= rep->len) rep = BStr_resize(rep, p + 1);
   rep->s[BitStr_index(p)] ^= _BS_BITMASK(BitStr_pos(p));
 }
 
-void BitString::set(int from, int to)
+void BitString::set(_G_int32_t from, _G_int32_t to)
 {
   if (from < 0 || from > to) error("Illegal bit index");
   if ((unsigned)(to) >= rep->len) rep = BStr_resize(rep, to+1);
@@ -587,7 +587,7 @@ void BitString::set(int from, int to)
   _BS_invert (xs, from, len);
 }
 
-void BitString::clear(int from, int to)
+void BitString::clear(_G_int32_t from, _G_int32_t to)
 {
   if (from < 0 || from > to) error("Illegal bit index");
   if ((unsigned)(to) >= rep->len) rep = BStr_resize(rep, to+1);
@@ -598,7 +598,7 @@ void BitString::clear(int from, int to)
   _BS_clear (xs, from, len);
 }
 
-void BitString::invert(int from, int to)
+void BitString::invert(_G_int32_t from, _G_int32_t to)
 {
   if (from < 0 || from > to) error("Illegal bit index");
   if ((unsigned)(to) >= rep->len) rep = BStr_resize(rep, to+1);
@@ -609,7 +609,7 @@ void BitString::invert(int from, int to)
 }
 
 
-int BitString::test(int from, int to) const
+int BitString::test(_G_int32_t from, _G_int32_t to) const
 {
   if (from < 0 || from > to || (unsigned)(from) >= rep->len) return 0;
   
@@ -619,19 +619,19 @@ int BitString::test(int from, int to) const
   return _BS_any (xs, from, len);
 }
 
-int BitString::next(int p, unsigned int b) const
+_G_int32_t BitString::next(_G_int32_t p, _G_uint32_t b) const
 {
   if ((unsigned)(++p) >= rep->len)
     return -1;
 
-  int ind = BitStr_index(p);
-  int pos = BitStr_pos(p);
-  int l = BitStr_len(rep->len);
+  _G_int32_t ind = BitStr_index(p);
+  _G_int32_t pos = BitStr_pos(p);
+  _G_int32_t l = BitStr_len(rep->len);
 
-  int j = ind;
+  _G_int32_t j = ind;
   const _BS_word* s = rep->s;
   _BS_word a = s[j] >> pos;
-  int i = pos;
+  _G_int32_t i = pos;
 
   if (b != 0)
   {
@@ -655,7 +655,7 @@ int BitString::next(int p, unsigned int b) const
   }
   else
   {
-    int last = BitStr_pos(rep->len);
+    _G_int32_t last = BitStr_pos(rep->len);
     if (j == l - 1)
     {
       for (; i < last; ++i)
@@ -697,13 +697,13 @@ int BitString::next(int p, unsigned int b) const
   }
 }
 
-int BitString::prev(int p, unsigned int b) const
+_G_int32_t BitString::prev(_G_int32_t p, _G_uint32_t b) const
 {
   if (--p < 0)
     return -1;
 
-  int ind = BitStr_index(p);
-  int pos = BitStr_pos(p);
+  _G_int32_t ind = BitStr_index(p);
+  _G_int32_t pos = BitStr_pos(p);
 
   const _BS_word* s = rep->s;
 
@@ -713,10 +713,10 @@ int BitString::prev(int p, unsigned int b) const
     pos = BitStr_pos(rep->len - 1);
   }
 
-  int j = ind;
+  _G_int32_t j = ind;
   _BS_word a = s[j];
 
-  int i = pos;
+  _G_int32_t i = pos;
   _BS_word maxbit = ((_BS_word)1) << pos;
 
   if (b != 0)
@@ -770,32 +770,32 @@ int BitString::prev(int p, unsigned int b) const
 }
 
 
-int BitString::search(int startx, int lengthx, 
-                      const _BS_word* ys, int starty, int lengthy) const
+_G_int32_t BitString::search(_G_int32_t startx, _G_int32_t lengthx, 
+                      const _BS_word* ys, _G_int32_t starty, _G_int32_t lengthy) const
 {
   const _BS_word* xs = rep->s;
-  int ylen = lengthy - starty;
-  int righty = lengthy - 1;
-  int rev = startx < 0;
+  _G_int32_t ylen = lengthy - starty;
+  _G_int32_t righty = lengthy - 1;
+  _G_int32_t rev = startx < 0;
   if (rev)
   {
-    int leftx = 0;
-    int rightx = lengthx + startx;
+    _G_int32_t leftx = 0;
+    _G_int32_t rightx = lengthx + startx;
     startx = rightx - ylen + 1;
     if (ylen == 0) return startx;
     if (starty < 0 || righty < 0 || startx < 0 || startx >= lengthx) return -1;
     
-    int xind = BitStr_index(startx);
-    int xpos = BitStr_pos(startx);
-    int yind = BitStr_index(starty);
-    int ypos = BitStr_pos(starty);
+    _G_int32_t xind = BitStr_index(startx);
+    _G_int32_t xpos = BitStr_pos(startx);
+    _G_int32_t yind = BitStr_index(starty);
+    _G_int32_t ypos = BitStr_pos(starty);
     
-    int rightxind = BitStr_index(rightx);
+    _G_int32_t rightxind = BitStr_index(rightx);
 
     _BS_word x = borrow_hi(xs, xind, rightxind, xpos);
   
-    int rightyind = BitStr_index(righty);
-    int rightypos = BitStr_pos(righty);
+    _G_int32_t rightyind = BitStr_index(righty);
+    _G_int32_t rightypos = BitStr_pos(righty);
     _BS_word y = borrow_hi(ys, yind, rightyind, ypos);
     _BS_word ymask;
     if (yind == rightyind)
@@ -805,13 +805,13 @@ int BitString::search(int startx, int lengthx,
     else
       ymask = ONES;
     
-    int p = startx;
+    _G_int32_t p = startx;
     for (;;)
     {
       if ((x & ymask) == y)
       {
-        int xi = xind;
-        int yi = yind;
+        _G_int32_t xi = xind;
+        _G_int32_t yi = yind;
         for (;;)
         {
           if (++yi > rightyind || ++xi > rightxind)
@@ -839,22 +839,22 @@ int BitString::search(int startx, int lengthx,
   else
   {
 
-    int rightx = lengthx - 1;
+    _G_int32_t rightx = lengthx - 1;
     if (ylen == 0) return startx;
     if (starty < 0 || righty < 0 || startx < 0 || startx >= lengthx) return -1;
     
-    int xind = BitStr_index(startx);
-    int xpos = BitStr_pos(startx);
-    int yind = BitStr_index(starty);
-    int ypos = BitStr_pos(starty);
+    _G_int32_t xind = BitStr_index(startx);
+    _G_int32_t xpos = BitStr_pos(startx);
+    _G_int32_t yind = BitStr_index(starty);
+    _G_int32_t ypos = BitStr_pos(starty);
 
-    int rightxind = BitStr_index(rightx);
+    _G_int32_t rightxind = BitStr_index(rightx);
 
     _BS_word x = borrow_hi(xs, xind, rightxind, xpos);
     _BS_word nextx = (xind >= rightxind) ? 0 : (xs[xind+1] >> xpos);
   
-    int rightyind = BitStr_index(righty);
-    int rightypos = BitStr_pos(righty);
+    _G_int32_t rightyind = BitStr_index(righty);
+    _G_int32_t rightypos = BitStr_pos(righty);
     _BS_word y = borrow_hi(ys, yind, rightyind, ypos);
     _BS_word ymask;
     if (yind == rightyind)
@@ -864,13 +864,13 @@ int BitString::search(int startx, int lengthx,
     else
       ymask = ONES;
   
-    int p = startx;
+    _G_int32_t p = startx;
     for (;;)
     {
       if ((x & ymask) == y)
       {
-        int xi = xind;
-        int yi = yind;
+        _G_int32_t xi = xind;
+        _G_int32_t yi = yind;
         for (;;)
         {
           if (++yi > rightyind || ++xi > rightxind)
@@ -905,42 +905,42 @@ int BitString::search(int startx, int lengthx,
 }
 
 
-int BitPattern::search(const _BS_word* xs, int startx, int lengthx) const
+_G_int32_t BitPattern::search(const _BS_word* xs, _G_int32_t startx, _G_int32_t lengthx) const
 {
   const _BS_word* ys = pattern.rep->s;
   const _BS_word* ms = mask.rep->s;
-  int righty = pattern.rep->len - 1;
-  int rightm = mask.rep->len - 1;
+  _G_int32_t righty = pattern.rep->len - 1;
+  _G_int32_t rightm = mask.rep->len - 1;
 
-  int rev = startx < 0;
+  _G_int32_t rev = startx < 0;
   if (rev)
   {
-    int leftx = 0;
-    int rightx = lengthx + startx;
+    _G_int32_t leftx = 0;
+    _G_int32_t rightx = lengthx + startx;
     startx = rightx - righty;
 
     if (righty < 0) return startx;
     if (startx < 0 || startx >= lengthx) return -1;
   
-    int xind = BitStr_index(startx);
-    int xpos = BitStr_pos(startx);
+    _G_int32_t xind = BitStr_index(startx);
+    _G_int32_t xpos = BitStr_pos(startx);
     
-    int rightxind = BitStr_index(rightx);
+    _G_int32_t rightxind = BitStr_index(rightx);
 
-    int rightmind = BitStr_index(rightm);
-    int rightyind = BitStr_index(righty);
+    _G_int32_t rightmind = BitStr_index(rightm);
+    _G_int32_t rightyind = BitStr_index(righty);
     
     _BS_word x = safe_borrow_hi(xs, xind, rightxind, xpos);
     _BS_word m = safe_borrow_hi(ms, 0, rightmind, 0);
     _BS_word y = safe_borrow_hi(ys, 0, rightyind, 0) & m;
     
-    int p = startx;
+    _G_int32_t p = startx;
     for (;;)
     {
       if ((x & m) == y)
       {
-        int xi = xind;
-        int yi = 0;
+        _G_int32_t xi = xind;
+        _G_int32_t yi = 0;
         for (;;)
         {
           if (++yi > rightyind || ++xi > rightxind)
@@ -965,18 +965,18 @@ int BitPattern::search(const _BS_word* xs, int startx, int lengthx) const
   else
   {
 
-    int rightx = lengthx - 1;
+    _G_int32_t rightx = lengthx - 1;
 
     if (righty < 0) return startx;
     if (startx < 0 || startx >= lengthx) return -1;
     
-    int xind = BitStr_index(startx);
-    int xpos = BitStr_pos(startx);
+    _G_int32_t xind = BitStr_index(startx);
+    _G_int32_t xpos = BitStr_pos(startx);
     
-    int rightxind = BitStr_index(rightx);
+    _G_int32_t rightxind = BitStr_index(rightx);
 
-    int rightmind = BitStr_index(rightm);
-    int rightyind = BitStr_index(righty);
+    _G_int32_t rightmind = BitStr_index(rightm);
+    _G_int32_t rightyind = BitStr_index(righty);
     
     _BS_word x = safe_borrow_hi(xs, xind, rightxind, xpos);
     _BS_word m = safe_borrow_hi(ms, 0, rightmind, 0);
@@ -984,13 +984,13 @@ int BitPattern::search(const _BS_word* xs, int startx, int lengthx) const
 
     _BS_word nextx = (xind >= rightxind) ? 0 : (xs[xind+1] >> xpos);
     
-    int p = startx;
+    _G_int32_t p = startx;
     for (;;)
     {
       if ((x & m) == y)
       {
-        int xi = xind;
-        int yi = 0;
+        _G_int32_t xi = xind;
+        _G_int32_t yi = 0;
         for (;;)
         {
           if (++yi > rightyind || ++xi > rightxind)
@@ -1021,14 +1021,14 @@ int BitPattern::search(const _BS_word* xs, int startx, int lengthx) const
   }
 }
 
-int BitString::match(int startx, int lengthx, int exact, 
-                     const _BS_word* ys, int starty, int yl) const
+int BitString::match(_G_int32_t startx, _G_int32_t lengthx, int exact, 
+                     const _BS_word* ys, _G_int32_t starty, _G_int32_t yl) const
 {
   const _BS_word* xs = rep->s;
-  int ylen = yl - starty;
-  int righty = yl - 1;
+  _G_int32_t ylen = yl - starty;
+  _G_int32_t righty = yl - 1;
 
-  int rightx;
+  _G_int32_t rightx;
   int rev = startx < 0;
   if (rev)
   {
@@ -1047,14 +1047,14 @@ int BitString::match(int startx, int lengthx, int exact,
   if (ylen == 0) return 1;
   if (righty < 0 || startx < 0 || startx >= lengthx) return 0;
   
-  int xi   = BitStr_index(startx);
-  int xpos = BitStr_pos(startx);
-  int yi   = BitStr_index(starty);
-  int ypos = BitStr_pos(starty);
+  _G_int32_t xi   = BitStr_index(startx);
+  _G_int32_t xpos = BitStr_pos(startx);
+  _G_int32_t yi   = BitStr_index(starty);
+  _G_int32_t ypos = BitStr_pos(starty);
 
-  int rightxind = BitStr_index(rightx);
-  int rightyind = BitStr_index(righty);
-  int rightypos = BitStr_pos(righty);
+  _G_int32_t rightxind = BitStr_index(rightx);
+  _G_int32_t rightyind = BitStr_index(righty);
+  _G_int32_t rightypos = BitStr_pos(righty);
 
   for (;;)
   {
@@ -1071,16 +1071,16 @@ int BitString::match(int startx, int lengthx, int exact,
   }
 }
 
-int BitPattern::match(const _BS_word* xs, int startx, 
-                      int lengthx, int exact) const
+int BitPattern::match(const _BS_word* xs, _G_int32_t startx, 
+                      _G_int32_t lengthx, int exact) const
 {
   const _BS_word* ys = pattern.rep->s;
-  int righty = pattern.rep->len - 1;
+  _G_int32_t righty = pattern.rep->len - 1;
   _BS_word* ms = mask.rep->s;
-  int rightm = mask.rep->len - 1;
+  _G_int32_t rightm = mask.rep->len - 1;
 
-  int rightx;
-  int rev = startx < 0;
+  _G_int32_t rightx;
+  _G_int32_t rev = startx < 0;
   if (rev)
   {
     rightx = lengthx + startx;
@@ -1098,13 +1098,13 @@ int BitPattern::match(const _BS_word* xs, int startx,
   if (righty < 0) return 1;
   if (startx < 0 || startx >= lengthx) return 0;
   
-  int xind = BitStr_index(startx);
-  int xpos = BitStr_pos(startx);
-  int yind = 0;
+  _G_int32_t xind = BitStr_index(startx);
+  _G_int32_t xpos = BitStr_pos(startx);
+  _G_int32_t yind = 0;
 
-  int rightxind = BitStr_index(rightx);
-  int rightyind = BitStr_index(righty);
-  int rightmind = BitStr_index(rightm);
+  _G_int32_t rightxind = BitStr_index(rightx);
+  _G_int32_t rightyind = BitStr_index(righty);
+  _G_int32_t rightmind = BitStr_index(rightm);
 
   for(;;)
   {
@@ -1124,8 +1124,8 @@ BitSubString& BitSubString::operator = (const BitString& y)
     return *this;
   BitStrRep* targ = S.rep;
 
-  unsigned int ylen = y.rep->len;
-  int sl = targ->len - len + ylen;
+  _G_uint32_t ylen = y.rep->len;
+  _G_int32_t sl = targ->len - len + ylen;
 
   if (y.rep == targ || ylen > len)
   {
@@ -1158,7 +1158,7 @@ BitSubString& BitSubString::operator = (const BitSubString& y)
   if (len == 0 || pos >= targ->len)
     return *this;
   
-  int sl = targ->len - len + y.len;
+  _G_int32_t sl = targ->len - len + y.len;
   
   if (y.S.rep == targ || y.len > len)
   {
@@ -1184,76 +1184,76 @@ BitSubString& BitSubString::operator = (const BitSubString& y)
   return *this;
 }
 
-BitSubString BitString::at(int first, int len)
+BitSubString BitString::at(_G_int32_t first, _G_int32_t len)
 {
   return _substr(first, len);
 }
 
-BitSubString BitString::before(int pos)
+BitSubString BitString::before(_G_int32_t pos)
 {
   return _substr(0, pos);
 }
 
-BitSubString BitString::after(int pos)
+BitSubString BitString::after(_G_int32_t pos)
 {
   return _substr(pos + 1, rep->len - (pos + 1));
 }
 
-BitSubString BitString::at(const BitString& y, int startpos)
+BitSubString BitString::at(const BitString& y, _G_int32_t startpos)
 {
-  int first = search(startpos, rep->len, y.rep->s, 0, y.rep->len);
+  _G_int32_t first = search(startpos, rep->len, y.rep->s, 0, y.rep->len);
   return _substr(first,  y.rep->len);
 }
 
-BitSubString BitString::before(const BitString& y, int startpos)
+BitSubString BitString::before(const BitString& y, _G_int32_t startpos)
 {
-  int last = search(startpos, rep->len, y.rep->s, 0, y.rep->len);
+  _G_int32_t last = search(startpos, rep->len, y.rep->s, 0, y.rep->len);
   return _substr(0, last);
 }
 
-BitSubString BitString::after(const BitString& y, int startpos)
+BitSubString BitString::after(const BitString& y, _G_int32_t startpos)
 {
-  int first = search(startpos, rep->len, y.rep->s, 0, y.rep->len);
+  _G_int32_t first = search(startpos, rep->len, y.rep->s, 0, y.rep->len);
   if (first >= 0) first += y.rep->len;
   return _substr(first, rep->len - first);
 }
 
 
-BitSubString BitString::at(const BitSubString& y, int startpos)
+BitSubString BitString::at(const BitSubString& y, _G_int32_t startpos)
 {
-  int first = search(startpos, rep->len, y.S.rep->s, y.pos, y.len);
+  _G_int32_t first = search(startpos, rep->len, y.S.rep->s, y.pos, y.len);
   return _substr(first, y.len);
 }
 
-BitSubString BitString::before(const BitSubString& y, int startpos)
+BitSubString BitString::before(const BitSubString& y, _G_int32_t startpos)
 {
-  int last = search(startpos, rep->len, y.S.rep->s, y.pos, y.len);
+  _G_int32_t last = search(startpos, rep->len, y.S.rep->s, y.pos, y.len);
   return _substr(0, last);
 }
 
-BitSubString BitString::after(const BitSubString& y, int startpos)
+BitSubString BitString::after(const BitSubString& y, _G_int32_t startpos)
 {
-  int first = search(startpos, rep->len, y.S.rep->s, y.pos, y.len);
+  _G_int32_t first = search(startpos, rep->len, y.S.rep->s, y.pos, y.len);
   if (first >= 0) first += y.len;
   return _substr(first, rep->len - first);
 }
 
-BitSubString BitString::at(const BitPattern& r, int startpos)
+BitSubString BitString::at(const BitPattern& r, _G_int32_t startpos)
 {
-  int first = r.search(rep->s, startpos, rep->len);
+  _G_int32_t first = r.search(rep->s, startpos, rep->len);
   return _substr(first, r.pattern.rep->len);
 }
 
 
-BitSubString BitString::before(const BitPattern& r, int startpos)
+BitSubString BitString::before(const BitPattern& r, _G_int32_t startpos)
 {
-  int first = r.search(rep->s, startpos, rep->len);
+  _G_int32_t first = r.search(rep->s, startpos, rep->len);
   return _substr(0, first);
 }
 
-BitSubString BitString::after(const BitPattern& r, int startpos)
+BitSubString BitString::after(const BitPattern& r, _G_int32_t startpos)
 {
-  int first = r.search(rep->s, startpos, rep->len);
+  _G_int32_t first = r.search(rep->s, startpos, rep->len);
   if (first >= 0) first += r.pattern.rep->len;
   return _substr(first, rep->len - first);
 }
@@ -1271,14 +1271,14 @@ BitSubString BitString::after(const BitPattern& r, int startpos)
 #endif
 
 BitString
-common_prefix (const BitString& x, const BitString& y, int startpos)
+common_prefix (const BitString& x, const BitString& y, _G_int32_t startpos)
      RETURNS(r)
 {
   RETURN_OBJECT(BitString, r);
-  unsigned int  xl = x.rep->len;
-  unsigned int  yl = y.rep->len;
+  _G_uint32_t  xl = x.rep->len;
+  _G_uint32_t  yl = y.rep->len;
 
-  unsigned int startx, starty;
+  _G_uint32_t startx, starty;
   if (startpos < 0)
   {
     startx = xl + startpos;
@@ -1292,17 +1292,17 @@ common_prefix (const BitString& x, const BitString& y, int startpos)
 
   const _BS_word* xs = &(x.rep->s[BitStr_index(startx)]);
   _BS_word a = *xs++;
-  unsigned int xp = startx;
+  _G_uint32_t xp = startx;
 
   const _BS_word* ys = &(y.rep->s[BitStr_index(starty)]);
   _BS_word b = *ys++;
-  unsigned int yp = starty;
+  _G_uint32_t yp = starty;
 
   for(; xp < xl && yp < yl; ++xp, ++yp)
   {
-    _BS_word xbit = ((_BS_word)1) << (BitStr_pos(xp));
-    _BS_word ybit = ((_BS_word)1) << (BitStr_pos(yp));
-    if (((a & xbit) == 0) != ((b & ybit) == 0))
+    _BS_word xbit = _BS_BITMASK (BitStr_pos(xp));
+    _BS_word ybit = _BS_BITMASK (BitStr_pos(yp));
+    if (((long)(((a & xbit)) == 0)) != ((long)((b & ybit) == 0)))
       break;
     if (xbit == MAXBIT)
       a = *xs++;
@@ -1315,14 +1315,14 @@ common_prefix (const BitString& x, const BitString& y, int startpos)
 
 
 BitString
-common_suffix (const BitString& x, const BitString& y, int startpos)
+common_suffix (const BitString& x, const BitString& y, _G_int32_t startpos)
      RETURNS(r)
 {
   RETURN_OBJECT(BitString, r);
-  unsigned int  xl = x.rep->len;
-  unsigned int  yl = y.rep->len;
+  _G_uint32_t  xl = x.rep->len;
+  _G_uint32_t  yl = y.rep->len;
 
-  unsigned int startx, starty;
+  _G_uint32_t startx, starty;
   if (startpos < 0)
   {
     startx = xl + startpos;
@@ -1336,17 +1336,17 @@ common_suffix (const BitString& x, const BitString& y, int startpos)
 
   const _BS_word* xs = &(x.rep->s[BitStr_index(startx)]);
   _BS_word a = *xs--;
-  int xp = startx;
+  _G_int32_t xp = startx;
 
   const _BS_word* ys = &(y.rep->s[BitStr_index(starty)]);
   _BS_word b = *ys--;
-  int yp = starty;
+  _G_int32_t yp = starty;
 
   for(; xp >= 0 && yp >= 0; --xp, --yp)
   {
-    _BS_word xbit = ((_BS_word)1) << (BitStr_pos(xp));
-    _BS_word ybit = ((_BS_word)1) << (BitStr_pos(yp));
-    if (((a & xbit) == 0) != ((b & ybit) == 0))
+    _BS_word xbit = _BS_BITMASK (BitStr_pos(xp));
+    _BS_word ybit = _BS_BITMASK (BitStr_pos(yp));
+    if (((long)(((a & xbit)) == 0)) != ((long)((b & ybit) == 0)))
       break;
     if (xbit == 1)
       a = *xs--;
@@ -1361,15 +1361,15 @@ BitString reverse (const BitString& x)
      RETURNS(r)
 {
   RETURN_OBJECT(BitString, r);
-  unsigned int  yl = x.rep->len;
+  _G_uint32_t yl = x.rep->len;
   BitStrRep* y = BStr_resize(0, yl);
   if (yl > 0)
   {
     const _BS_word* ls = x.rep->s;
     _BS_word lm = 1;
     _BS_word* rs = &(y->s[BitStr_index(yl - 1)]);
-    _BS_word rm = ((_BS_word)1) << (BitStr_pos(yl - 1));
-    for (unsigned int  l = 0; l < yl; ++l)
+    _BS_word rm = _BS_BITMASK (BitStr_pos(yl - 1));
+    for (_G_uint32_t l = 0; l < yl; ++l)
     {
       if (*ls & lm)
         *rs |= rm;
@@ -1398,15 +1398,15 @@ atoBitString (const char* s, char f, char t)
      RETURNS(res)
 {
   RETURN_OBJECT(BitString, res);
-  int sl = strlen(s);
+  _G_int32_t sl = strlen(s);
   BitStrRep* r = BStr_resize(0, sl);
   if (sl != 0)
   {
-    unsigned int  rl = 0;
+    _G_uint32_t  rl = 0;
     _BS_word* rs = r->s;
     _BS_word a = 0;
     _BS_word m = 1;
-    unsigned int  i = 0;
+    _G_uint32_t  i = 0;
     for(;;)
     {
       char ch = s[i];
@@ -1443,10 +1443,10 @@ atoBitPattern (const char* s, char f,char t,char x)
      RETURNS(r)
 {
   RETURN_OBJECT(BitPattern, r);
-  int sl = strlen(s);
+  _G_int32_t sl = strlen(s);
   if (sl != 0)
   {
-    unsigned int  rl = 0;
+    _G_uint32_t  rl = 0;
     r.pattern.rep = BStr_resize(r.pattern.rep, sl);
     r.mask.rep = BStr_resize(r.mask.rep, sl);
     _BS_word* rs = r.pattern.rep->s;
@@ -1454,7 +1454,7 @@ atoBitPattern (const char* s, char f,char t,char x)
     _BS_word a = 0;
     _BS_word b = 0;
     _BS_word m = 1;
-    unsigned int  i = 0;
+    _G_uint32_t  i = 0;
     for(;;)
     {
       char ch = s[i];
@@ -1501,12 +1501,12 @@ extern AllocRing _libgxx_fmtq;
 
 void BitString::printon (ostream& os, char f, char t) const
 {
-  unsigned int  xl = rep->len;
+  _G_uint32_t  xl = rep->len;
   const _BS_word* ptr = rep->s;
   register streambuf *sb = os.rdbuf();
   _BS_word a = 0;
 
-  for (unsigned int  i = 0; i < xl; ++i)
+  for (_G_uint32_t  i = 0; i < xl; ++i)
   {
     if (i % BITSTRBITS == 0)
       a = *ptr++;
@@ -1516,7 +1516,7 @@ void BitString::printon (ostream& os, char f, char t) const
 }
 const char* BitStringtoa(const BitString& x, char f, char t)
 {
-  int wrksiz = x.length() + 2;
+  _G_int32_t wrksiz = x.length() + 2;
   char* fmtbase = (char *) _libgxx_fmtq.alloc(wrksiz);
   ostrstream stream(fmtbase, wrksiz);
   
@@ -1534,11 +1534,11 @@ ostream& operator << (ostream& s, const BitString& x)
 
 const char* BitPatterntoa(const BitPattern& p, char f,char t,char x)
 {
-  unsigned int  pl = p.pattern.rep->len;
-  unsigned int  ml = p.mask.rep->len;
-  unsigned int  l = (pl <= ml)? pl : ml;
+  _G_uint32_t  pl = p.pattern.rep->len;
+  _G_uint32_t  ml = p.mask.rep->len;
+  _G_uint32_t  l = (pl <= ml)? pl : ml;
 
-  int wrksiz = l + 2;
+  _G_int32_t wrksiz = l + 2;
   char* fmtbase = (char *) _libgxx_fmtq.alloc(wrksiz);
   ostrstream stream(fmtbase, wrksiz);
   
@@ -1549,9 +1549,9 @@ const char* BitPatterntoa(const BitPattern& p, char f,char t,char x)
 
 void BitPattern::printon(ostream& s, char f,char t,char x) const
 {
-  unsigned int  pl = pattern.rep->len;
-  unsigned int  ml = mask.rep->len;
-  unsigned int  l = (pl <= ml)? pl : ml;
+  _G_uint32_t  pl = pattern.rep->len;
+  _G_uint32_t  ml = mask.rep->len;
+  _G_uint32_t  l = (pl <= ml)? pl : ml;
   register streambuf *sb = s.rdbuf();
 
   const _BS_word* ps = pattern.rep->s;
@@ -1559,7 +1559,7 @@ void BitPattern::printon(ostream& s, char f,char t,char x) const
   _BS_word a = 0;
   _BS_word m = 0;
 
-  for (unsigned int  i = 0; i < l; ++i)
+  for (_G_uint32_t  i = 0; i < l; ++i)
   {
     if (i % BITSTRBITS == 0)
     {
